@@ -4,7 +4,6 @@ import ntsbuildtools.io
 from ntsbuildtools.teams.card_template import TeamsCardTemplate
 from ntsbuildtools.markdown.comments import MarkdownComment
 from ntsbuildtools.util import hasattr_nonempty_str
-from ntsbuildtools.markdown.fragmentation import splitter as markdown_splitter
 
 class TeamsMessageTypes(enum.Enum):
     PULL_REQUEST = 'pull-request'
@@ -68,18 +67,16 @@ class PullRequestUpdateCard(TeamsCardTemplate):
 
 class BuildFailCard(TeamsCardTemplate):
     def __init__(self, args): 
-        required_arguments = {'jenkins_build_id', 'jenkins_build_url', 'status', 'build_type', 'pull_request_id'}
-        optional_arguments = {'jenkins_job_name', 'pipeline_name', 'playbook_limit', 'pull_request_url'}
+        required_arguments = {'jenkins_build_id', 'jenkins_build_url', 'status', 'build_type'}
+        optional_arguments = {'jenkins_job_name', 'pipeline_name', 'playbook_limit', 'pull_request_id', 'pull_request_url'}
         super().__init__(required_arguments, optional_arguments, args)
 
     def build(self, args):
         self.set_title(f'{args.build_type} {args.status.capitalize()}')
         build_facts = self.add_section()
         build_facts.add_fact("Jenkins Build", f'[Build #{args.jenkins_build_id}]({args.jenkins_build_url})')
-        if hasattr_nonempty_str(args, 'pull_request_url'):  # Optional
+        if hasattr_nonempty_str(args, 'pull_request_id') and hasattr_nonempty_str(args, 'pull_request_url'):
             build_facts.add_fact("Pull Request", f"[PR #{args.pull_request_id}]({args.pull_request_url})")
-        else:
-            build_facts.add_fact("Pull Request", f"PR #{args.pull_request_id}")
         if hasattr_nonempty_str(args, 'playbook_limit'):  # Optional
             build_facts.add_fact("Playbook limit", args.playbook_limit)
         if hasattr_nonempty_str(args, 'jenkins_job_name'):  # Optional
